@@ -1036,12 +1036,13 @@ do_sound_action (CsdMediaKeysManager *manager,
         case C_DESKTOP_MEDIA_KEY_VOLUME_UP:
                 new_muted = FALSE;
                 /* When coming out of mute only increase the volume if it was 0 */
-                if (!old_muted || old_vol_pa == 0)
+                if (!old_muted || old_vol_pa == 0) {
                         if (old_vol_pa % vol_step_pa > 0 && !CROSSING_PA_NORM (old_vol_pa, vol_step_pa)) {
                                 new_vol_pa = MIN (old_vol_pa / vol_step_pa * vol_step_pa, max_vol_pa);
                         } else {
                                 new_vol_pa = MIN (old_vol_pa / vol_step_pa * vol_step_pa + vol_step_pa, max_vol_pa);
                         }
+                }
                 break;
         }
 
