@@ -45,10 +45,14 @@
 #include "xsettings-manager.h"
 #include "fontconfig-monitor.h"
 
+#define GNOME_DESKTOP_USE_UNSTABLE_API
+#include <libcinnamon-desktop/gnome-rr.h>
+
 #define CINNAMON_XSETTINGS_MANAGER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CINNAMON_TYPE_XSETTINGS_MANAGER, CinnamonSettingsXSettingsManagerPrivate))
 
 #define MOUSE_SETTINGS_SCHEMA     "org.cinnamon.settings-daemon.peripherals.mouse"
 #define INTERFACE_SETTINGS_SCHEMA "org.cinnamon.desktop.interface"
+#define INTERFACE_WM_SETTINGS_SCHEMA "org.cinnamon.desktop.wm.preferences"
 #define SOUND_SETTINGS_SCHEMA     "org.cinnamon.desktop.sound"
 #define PRIVACY_SETTINGS_SCHEMA   "org.cinnamon.desktop.privacy"
 
@@ -220,14 +224,6 @@
  */
 #define DPI_FALLBACK 96
 
-/* The minimum resolution at which we turn on a window-scale of 2 */
-#define HIDPI_LIMIT (DPI_FALLBACK * 2)
-
-/* The minimum screen height at which we turn on a window-scale of 2;
- * below this there just isn't enough vertical real estate for GNOME
- * apps to work, and it's better to just be tiny */
-#define HIDPI_MIN_HEIGHT 1500
-
 typedef struct _TranslationEntry TranslationEntry;
 typedef void (* TranslationFunc) (CinnamonSettingsXSettingsManager *manager,
                                   TranslationEntry      *trans,
@@ -261,8 +257,6 @@ enum {
         CSD_XSETTINGS_ERROR_INIT
 };
 
-static void     cinnamon_xsettings_manager_class_init  (CinnamonSettingsXSettingsManagerClass *klass);
-static void     cinnamon_xsettings_manager_init        (CinnamonSettingsXSettingsManager      *xsettings_manager);
 static void     cinnamon_xsettings_manager_finalize    (GObject                  *object);
 
 G_DEFINE_TYPE (CinnamonSettingsXSettingsManager, cinnamon_xsettings_manager, G_TYPE_OBJECT)
@@ -338,6 +332,62 @@ translate_string_string_toolbar (CinnamonSettingsXSettingsManager *manager,
         }
 }
 
+static void
+translate_string_string_window_buttons (CinnamonSettingsXSettingsManager *manager,
+                                 TranslationEntry      *trans,
+                                 GVariant              *value)
+{
+        int         i;
+        const char *tmp;
+        gchar *ptr, *final_str;
+
+        /* This is kind of a workaround. "menu" is useless in metacity titlebars
+         * it duplicates the same features as the right-click menu.
+         * In CSD windows on the hand it is required to show unique featues.
+         */
+
+        tmp = g_variant_get_string (value, NULL);
+
+        /* Check if menu is in the setting string already */
+        ptr = g_strstr_len (tmp, -1, "menu");
+
+        if (!ptr) {
+            /* If it wasn't there already, we add it... */
+
+            /* Simple cases, :* - all items on right, just prepend menu on left side*/
+            if (g_str_has_prefix (tmp, ":")) {
+                final_str = g_strdup_printf ("menu%s", tmp);
+            }
+            else
+            /* All items on left... * (no :), append menu - we want actual window
+               controls on the outside */
+            if (!g_strstr_len (tmp, -1, ":")) {
+                final_str = g_strdup_printf ("%s,menu", tmp);
+            }
+            else {
+                /* Items on both sides, split it, append menu to the lefthand, and re-
+                 * construct the string with the : separator */
+
+                gchar **split = g_strsplit (tmp, ":", 2);
+
+                final_str = g_strdup_printf ("%s,menu:%s", split[0], split[1]);
+
+                g_strfreev (split);
+            }
+        } else {
+            /* If menu was already included, just copy the original string */
+            final_str = g_strdup (tmp);
+        }
+
+        for (i = 0; manager->priv->managers [i]; i++) {
+                xsettings_manager_set_string (manager->priv->managers [i],
+                                              trans->xsetting_name,
+                                              final_str);
+        }
+
+        g_free (final_str);
+}
+
 static TranslationEntry translations [] = {
         { "org.cinnamon.settings-daemon.peripherals.mouse", "double-click",   "Net/DoubleClickTime",  translate_int_int },
         { "org.cinnamon.settings-daemon.peripherals.mouse", "drag-threshold", "Net/DndDragThreshold", translate_int_int },
@@ -355,7 +405,6 @@ static TranslationEntry translations [] = {
         { "org.cinnamon.desktop.interface", "gtk-timeout-initial",    "Gtk/TimeoutInitial",      translate_int_int },
         { "org.cinnamon.desktop.interface", "gtk-timeout-repeat",     "Gtk/TimeoutRepeat",       translate_int_int },
         { "org.cinnamon.desktop.interface", "gtk-color-scheme",       "Gtk/ColorScheme",         translate_string_string },
-        { "org.cinnamon.desktop.interface", "gtk-decoration-layout",  "Gtk/DecorationLayout",    translate_string_string },
         { "org.cinnamon.desktop.interface", "gtk-im-preedit-style",   "Gtk/IMPreeditStyle",      translate_string_string },
         { "org.cinnamon.desktop.interface", "gtk-im-status-style",    "Gtk/IMStatusStyle",       translate_string_string },
         { "org.cinnamon.desktop.interface", "gtk-im-module",          "Gtk/IMModule",            translate_string_string },
@@ -365,7 +414,10 @@ static TranslationEntry translations [] = {
         { "org.cinnamon.desktop.interface", "menubar-accel",          "Gtk/MenuBarAccel",        translate_string_string },
         { "org.cinnamon.desktop.interface", "enable-animations",      "Gtk/EnableAnimations",    translate_bool_int },
         { "org.cinnamon.desktop.interface", "cursor-theme",           "Gtk/CursorThemeName",     translate_string_string },
-
+        { "org.cinnamon.desktop.wm.preferences", "button-layout",  "Gtk/DecorationLayout",    translate_string_string_window_buttons },
+        { "org.cinnamon.desktop.wm.preferences", "action-double-click-titlebar",  "Gtk/TitlebarDoubleClick",    translate_string_string },
+        { "org.cinnamon.desktop.wm.preferences", "action-middle-click-titlebar",  "Gtk/TitlebarMiddleClick",    translate_string_string },
+        { "org.cinnamon.desktop.wm.preferences", "action-right-click-titlebar",  "Gtk/TitlebarRightClick",    translate_string_string },
         { "org.cinnamon.settings-daemon.plugins.xsettings", "show-input-method-menu", "Gtk/ShowInputMethodMenu", translate_bool_int },
         { "org.cinnamon.settings-daemon.plugins.xsettings", "show-unicode-menu",      "Gtk/ShowUnicodeMenu",     translate_bool_int },
         { "org.cinnamon.settings-daemon.plugins.xsettings", "automatic-mnemonics",    "Gtk/AutoMnemonics",       translate_bool_int },
@@ -416,52 +468,25 @@ static int
 get_window_scale (CinnamonSettingsXSettingsManager *manager)
 {
     GSettings  *interface_settings;
+    GError *error = NULL;
     int window_scale;
-    GdkRectangle rect;
-    GdkDisplay *display;
-    GdkScreen *screen;
-    int width_mm, height_mm;
-    int monitor_scale;
-    double dpi_x, dpi_y;
 
     interface_settings = g_hash_table_lookup (manager->priv->settings, INTERFACE_SETTINGS_SCHEMA);
     window_scale = g_settings_get_uint (interface_settings, SCALING_FACTOR_KEY);
-        if (window_scale == 0) {
-                int primary;
 
-                display = gdk_display_get_default ();
-                screen = gdk_display_get_default_screen (display);
-                primary = gdk_screen_get_primary_monitor (screen);
-                gdk_screen_get_monitor_geometry (screen, primary, &rect);
-                width_mm = gdk_screen_get_monitor_width_mm (screen, primary);
-                height_mm = gdk_screen_get_monitor_height_mm (screen, primary);
-                monitor_scale = gdk_screen_get_monitor_scale_factor (screen, primary);
+    if (window_scale == 0) {
+            GnomeRRScreen *screen = gnome_rr_screen_new (gdk_screen_get_default (), &error);
 
-                window_scale = 1;
+            if (!error) {
+                window_scale = gnome_rr_screen_calculate_best_global_scale (screen, -1);
+                g_object_unref (screen);
+            } else {
+                g_warning ("Could not get/create GnomeRRScreen instance: %s", error->message);
+                g_error_free (error);
+            }
+    }
 
-                if (rect.height < HIDPI_MIN_HEIGHT)
-                    goto out;
-
-                /* Some monitors/TV encode the aspect ratio (16/9 or 16/10) instead of the physical size */
-                if ((width_mm == 160 && height_mm == 90) ||
-                    (width_mm == 160 && height_mm == 100) ||
-                    (width_mm == 16 && height_mm == 9) ||
-                    (width_mm == 16 && height_mm == 10))
-                    goto out;
-
-                if (width_mm > 0 && height_mm > 0) {
-                        dpi_x = (double)rect.width * monitor_scale / (width_mm / 25.4);
-                        dpi_y = (double)rect.height * monitor_scale / (height_mm / 25.4);
-                        /* We don't completely trust these values so both
-                           must be high, and never pick higher ratio than
-                          2 automatically */
-                        if (dpi_x > HIDPI_LIMIT && dpi_y > HIDPI_LIMIT)
-                                window_scale = 2;
-                }
-        }
-
-out:
-        return window_scale;
+    return window_scale;
 }
 
 typedef struct {
@@ -934,6 +959,8 @@ cinnamon_xsettings_manager_start (CinnamonSettingsXSettingsManager *manager,
                              MOUSE_SETTINGS_SCHEMA, g_settings_new (MOUSE_SETTINGS_SCHEMA));
         g_hash_table_insert (manager->priv->settings,
                              INTERFACE_SETTINGS_SCHEMA, g_settings_new (INTERFACE_SETTINGS_SCHEMA));
+        g_hash_table_insert (manager->priv->settings,
+                             INTERFACE_WM_SETTINGS_SCHEMA, g_settings_new (INTERFACE_WM_SETTINGS_SCHEMA));
         g_hash_table_insert (manager->priv->settings,
                              SOUND_SETTINGS_SCHEMA, g_settings_new (SOUND_SETTINGS_SCHEMA));
         g_hash_table_insert (manager->priv->settings,
